@@ -22,7 +22,8 @@ enUi = ['button', 'checkbox', 'field', 'column', 'area', 'box', 'role', 'user',
         'RFx', 'search', 'page', 'tab', 'panel', 'option', 'dialog', 'status', 'tag', 'symbol', 'sign', 'label', 'scenario', 'link',
         'auction', 'events', 'checkboxes', 'columns', 'lines', 'answers', 'answer', 'responses', 'response', 'buttons', 'fields',
         'tabs', 'icon', 'icons', 'users', 'widget', 'widgets', 'window', 'windows', 'dialog box', 'dialog boxes', 'modal window',
-        'modal windows', 'dialog window', 'dialog windows', 'homepage', 'folder', 'folders', 'file', 'files', 'project', 'projects']
+        'modal windows', 'dialog window', 'dialog windows', 'homepage', 'folder', 'folders', 'file', 'files', 'project', 'projects',
+        'image', 'images']
 
 # Configuração da API de tradução
 
@@ -45,7 +46,7 @@ sourceDir = '_'.join(sourceLang.split('-')).lower()
 
 mdRegex = re.compile(r'''(\]\(.+?\)[\W ]?)|          # referência de imagem ou link
                          (uid:\s?[\w.]+)|            # âncora de link no cabeçalho
-                         (\{\{.*?\}\}[\W ]+?)|       # nome de UI localizado pelo Zanata
+                         (\{\{.*?\}\}[\W ]+?)|       # nome de elemento de UI
                          (:{3}\s*[a-z]*)|            # demarcador de bloco de ênfase customizado para o Docs 2.0
                          (`{1,3}.+?`{1,3}[\W ]?)|    # bloco de código
                          (<.+?>)|                    # HTML
@@ -82,9 +83,15 @@ def ProcessFiles(sourceFile):
                 PrGreen('\n Traslating Markdown from ' + sourceLang + ' to ' + targetLangs[i])
                 if sourceLang[:2] == 'en':
                     slicedUi = re.split(r'(\{\{.*?\}\} [a-zA-Z]+)', sourceContent)
+                    slicedItalic = re.split(r'(\*.*?\* [a-zA-Z]+)', sourceContent)
+                    slicedBold = re.split(r'(\*\*.*?\*\* [a-zA-Z]+)', sourceContent)
                     for j in range(len(slicedUi)):
                         if re.fullmatch(r'\{\{.*?\}\} [a-zA-Z]+', slicedUi[j]) and re.search(r'(?<=\}\} ).+', slicedUi[j]).group().casefold() in enUi:
                             slicedUi[j] = ' '.join(re.split(r'(?<=\}\}) ', slicedUi[j])[::-1])
+                        if re.fullmatch(r'\*.*?\* [a-zA-Z]+', slicedItalic[j]) and re.search(r'(?<=\}\} ).+', slicedItalic[j]).group().casefold() in enUi:
+                            slicedItalic[j] = ' '.join(re.split(r'(?<=\}\}) ', slicedItalic[j])[::-1])
+                        if re.fullmatch(r'\*\*.*?\*\* [a-zA-Z]+', slicedBold[j]) and re.search(r'(?<=\}\} ).+', slicedBold[j]).group().casefold() in enUi:
+                            slicedBold[j] = ' '.join(re.split(r'(?<=\}\}) ', slicedBold[j])[::-1])
                     sourceContent = ''.join(slicedUi)
                 slicedApple = list(filter(lambda x: x != '' and x is not None, mdRegex.split(sourceContent)))
                 for piece in slicedApple:
